<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sq">
<context>
    <name>FilterableComboBox</name>
    <message>
        <location filename="../filterablecombobox.cpp" line="12"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SelectLayoutDialog</name>
    <message>
        <location filename="../selectlayoutdialog.ui" line="14"/>
        <source>Select Keyboard Layout and Variant</source>
        <translation>Përzgjidhni Skemë dhe Variant Tastiere</translation>
    </message>
    <message>
        <location filename="../selectlayoutdialog.ui" line="29"/>
        <source>Layout</source>
        <translation>Skemë</translation>
    </message>
    <message>
        <location filename="../selectlayoutdialog.ui" line="47"/>
        <source>Variants</source>
        <translation>Variante</translation>
    </message>
    <message>
        <location filename="../selectlayoutdialog.cpp" line="57"/>
        <source>No Variant</source>
        <translation>Pa Variant</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../window.ui" line="14"/>
        <location filename="../window.cpp" line="114"/>
        <location filename="../window.cpp" line="118"/>
        <source>System Keyboard</source>
        <translation>Tastierë Sistemi</translation>
    </message>
    <message>
        <location filename="../window.ui" line="28"/>
        <source>Layouts</source>
        <translation>Skema</translation>
    </message>
    <message>
        <location filename="../window.ui" line="34"/>
        <source>Keyboard Model</source>
        <translation>Model Tastiere</translation>
    </message>
    <message>
        <source>search</source>
        <translation type="vanished">kërko</translation>
    </message>
    <message>
        <location filename="../window.ui" line="46"/>
        <source>Keyboard Layouts</source>
        <translation>Skema Tastiere</translation>
    </message>
    <message>
        <location filename="../window.ui" line="136"/>
        <source>Hotkeys</source>
        <translation>Kombinime</translation>
    </message>
    <message>
        <location filename="../window.ui" line="159"/>
        <source>Advanced</source>
        <translation>Të mëtejshme</translation>
    </message>
    <message>
        <location filename="../window.ui" line="187"/>
        <source>Help</source>
        <translation>Ndihmë</translation>
    </message>
    <message>
        <location filename="../window.cpp" line="189"/>
        <location filename="../window.cpp" line="214"/>
        <location filename="../window.cpp" line="240"/>
        <source>Error</source>
        <translation>Gabim</translation>
    </message>
    <message>
        <location filename="../window.cpp" line="189"/>
        <location filename="../window.cpp" line="214"/>
        <location filename="../window.cpp" line="240"/>
        <source>Failed to open file: </source>
        <translation>S’u arrit të hapet kartelë:</translation>
    </message>
    <message>
        <location filename="../window.cpp" line="240"/>
        <source>Most settings will not be loaded</source>
        <translation>Shumica e rregullimeve s’do të ngarkohen</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation type="vanished">Çaktivizuar</translation>
    </message>
</context>
</TS>
